#!/usr/bin/env python3

import os
import unittest
import yaml
import amulet
import sys
import requests
import time

seconds_to_wait =  3600


class BundleTest(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
         
         d = amulet.Deployment(juju_env='local', series='trusty') 
         local_path = os.path.join(os.path.dirname(__file__), 'local.yaml')
         with open(local_path, "r") as fd:
            config = yaml.safe_load(fd)
              

        #Add charms and accept license "Software doesn't actually install until you accept the license"
         d.add('ibm-mobilefirst-server')
         d.add('websphere-liberty' , placement="ibm-mobilefirst-server")
         d.configure('websphere-liberty', { 'accept-ibm-websphere-license': True })
         d.configure('websphere-liberty', { 'accept-ibm-java-license': True })
         d.add('ibm-db2')
         d.add('ibm-mfs-helper')
         d.setup(seconds_to_wait)
         d.sentry.wait(seconds_to_wait)
         cls.d = d
         print ('Calling juju action: db2')
         uuid = d.action_do('ibm-db2/0', 'download', {"username": config.get('ibm-repo').get('sftp_user_name'), "password": config.get('ibm-repo').get('sftp_password'), "packagename": config.get('ibm-repo').get('db_package_name'), "host": config.get('ibm-repo').get('sftp_host')})
         print('juju action completed for db2')
         
         results = d.action_fetch(uuid, 1200)
         if 'outcome' in results:
            if results['outcome'] == 'success':
                print ('Downloaded db2 packages from repository.')
            else:
                print ('Download of db2 packages from repository failed.')
         else:
            print ('Download of db2 packages from repository failed. A timeout could have occurred.')
         d.configure('ibm-db2', {'accept-ibm-db2-license': True})
         time.sleep(120)
        
         print ('Calling juju action: mobilefirst server')
         uuid = d.action_do('ibm-mobilefirst-server/0', 'download', {"username": config.get('ibm-repo').get('sftp_user_name'), "password": config.get('ibm-repo').get('sftp_password'), "packagedir": config.get('ibm-repo').get('mfsdir_name'), "host": config.get('ibm-repo').get('sftp_host')})
         print('juju action completed for mobilefirst server')
        
       
         mfsresults = d.action_fetch(uuid, 1200)
         if 'outcome' in mfsresults:
             if mfsresults['outcome'] == 'success':
                 print ('Downloaded mobilefirst server packages from repository.')
             else:
                 print ('Download of mobilefirst server packages from repository failed.')
         else:
             print ('Download of mobilefirst server packages from repository failed. A timeout could have occurred.')
         #Accept license for IM
         d.configure('ibm-mobilefirst-server', {'accept-ibm-im-license': True})
              
         #Accept license for MobileFirst Server
         d.configure('ibm-mobilefirst-server', {'accept-ibm-mobilefirstserver-license': True})
         time.sleep(120)
         
         d.relate('ibm-mfs-helper:db', 'ibm-db2:db')
         time.sleep(120)
         #Add relation mobilefirst server to mfs-helper
         d.relate('ibm-mobilefirst-server:helper', 'ibm-mfs-helper:helper')
         time.sleep(120)
         #Add relation mobilefirst server to db2
         d.relate('ibm-mobilefirst-server:db', 'ibm-db2:db')
         time.sleep(120)
         #Add relation mobilefirst server to websphere-liberty
         d.relate('ibm-mobilefirst-server:website', 'websphere-liberty:website')
         d.setup(seconds_to_wait)
         d.sentry.wait(seconds_to_wait)
         cls.d = d

    def test_case(self):
        self.assertTrue(self.d.deployed)
	unit_manager_0 = self.d.sentry.unit['ibm-mobilefirst-server/0']
	address = unit_manager_0.info['public-address']
	pass

    def test_website(self):
        unit = self.d.sentry.unit['ibm-mobilefirst-server/0']
        url  = 'http://%s:9081/appcenterconsole' % unit.info['public-address']
        response = requests.get(url)
        # Raise an exception if the url was not a valid web page.
        response.raise_for_status()

if __name__ == '__main__':
    unittest.main()
